@@ -5,7 +5,6 @@ from sql.conditionals import Case
 
 from trytond.model import ModelView, ModelSQL, fields
 from trytond.pyson import Eval
-from trytond.transaction import Transaction
 from trytond import backend
 
 __all__ = ['ContactMechanism']
@@ -94,8 +93,7 @@ class ContactMechanism(ModelSQL, ModelView):
     @classmethod
     def __register__(cls, module_name):
         TableHandler = backend.get('TableHandler')
-        cursor = Transaction().cursor
-        table = TableHandler(cursor, cls, module_name)
+        table = TableHandler(cls, module_name)
 
         super(ContactMechanism, cls).__register__(module_name)
 
